@@ -14,7 +14,8 @@ class Db
   require 'tempfile'
 
   include Msf::Ui::Console::CommandDispatcher
-
+  include Msf::Ui::Console::CommandDispatcher::Common
+ 
   #
   # The dispatcher's name.
   #
@@ -92,7 +93,9 @@ class Db
 
   def cmd_workspace(*args)
     return unless active?
+    search_term = nil
   ::ActiveRecord::Base.connection_pool.with_connection {
+    search_term = nil
     while (arg = args.shift)
       case arg
       when '-h','--help'
@@ -106,8 +109,10 @@ class Db
         delete_all = true
       when '-r','--rename'
         renaming = true
-      when '-v'
+      when '-v','--verbose'
         verbose = true
+      when '-S', '--search'
+        search_term = args.shift
       else
         names ||= []
         names << arg
@@ -177,19 +182,26 @@ class Db
       workspace = framework.db.workspace
 
       unless verbose
-        framework.db.workspaces.each do |ws|
-          pad = (ws == workspace) ? '* ' : '  '
-          print_line("#{pad}#{ws.name}")
+        current = nil
+        framework.db.workspaces.sort_by {|s| s.name}.each do |s|
+          if s.name == workspace.name
+            current = s.name
+          else
+            print_line("  #{s.name}")
+          end
         end
+        print_line("%red* #{current}%clr") unless current.nil?
         return
       end
+      workspace = framework.db.workspace
 
       col_names = %w{current name hosts services vulns creds loots notes}
 
       tbl = Rex::Text::Table.new(
-        'Header'    => 'Workspaces',
-        'Columns'   => col_names,
-        'SortIndex' => -1
+        'Header'     => 'Workspaces',
+        'Columns'    => col_names,
+        'SortIndex'  => -1,
+        'SearchTerm' => search_term
       )
 
       # List workspaces
@@ -454,11 +466,16 @@ class Db
       return
     end
 
+    cp_hsh = {}
+    col_names.map do |col|
+      cp_hsh[col] = { 'MaxChar' => 52 }
+    end
     # If we got here, we're searching.  Delete implies search
     tbl = Rex::Text::Table.new(
       {
-        'Header'    => "Hosts",
-        'Columns'   => col_names,
+        'Header'  => "Hosts",
+        'Columns' => col_names,
+        'ColProps' => cp_hsh,
         'SortIndex' => order_by
       })
 
@@ -525,7 +542,12 @@ class Db
           rhosts << addr
         end
         if mode == [:delete]
-          host.destroy
+          begin
+            host.destroy
+          rescue # refs suck
+            print_error("Forcibly deleting #{host.address}")
+            host.delete
+          end
           delete_count += 1
         end
       end
@@ -1316,6 +1338,7 @@ class Db
     print_line "    IP360 ASPL"
     print_line "    IP360 XML v3"
     print_line "    Libpcap Packet Capture"
+    print_line "    Masscan XML"
     print_line "    Metasploit PWDump Export"
     print_line "    Metasploit XML"
     print_line "    Metasploit Zip Export"
@@ -1486,6 +1509,8 @@ class Db
       print_status("Usage: db_nmap [--save | [--help | -h]] [nmap options]")
       return
     end
+
+    save = false
     arguments = []
     while (arg = args.shift)
       case arg
@@ -1588,7 +1613,7 @@ class Db
       print_error(err_line.strip)
     end
 
-    tabs
+    return tabs
   end
 
   #
@@ -1714,43 +1739,6 @@ class Db
     print_line
   end
 
-  #
-  # Set RHOSTS in the +active_module+'s (or global if none) datastore from an array of addresses
-  #
-  # This stores all the addresses to a temporary file and utilizes the
-  # <pre>file:/tmp/filename</pre> syntax to confer the addrs.  +rhosts+
-  # should be an Array.  NOTE: the temporary file is *not* deleted
-  # automatically.
-  #
-  def set_rhosts_from_addrs(rhosts)
-    if rhosts.empty?
-      print_status("The list is empty, cowardly refusing to set RHOSTS")
-      return
-    end
-    if active_module
-      mydatastore = active_module.datastore
-    else
-      # if there is no module in use set the list to the global variable
-      mydatastore = self.framework.datastore
-    end
-
-    if rhosts.length > 5
-      # Lots of hosts makes 'show options' wrap which is difficult to
-      # read, store to a temp file
-      rhosts_file = Rex::Quickfile.new("msf-db-rhosts-")
-      mydatastore['RHOSTS'] = 'file:'+rhosts_file.path
-      # create the output file and assign it to the RHOSTS variable
-      rhosts_file.write(rhosts.join("\n")+"\n")
-      rhosts_file.close
-    else
-      # For short lists, just set it directly
-      mydatastore['RHOSTS'] = rhosts.join(" ")
-    end
-
-    print_line "RHOSTS => #{mydatastore['RHOSTS']}"
-    print_line
-  end
-
   def db_find_tools(tools)
     missed  = []
     tools.each do |name|
@@ -1843,55 +1831,6 @@ class Db
   # Miscellaneous option helpers
   #
 
-  # Parse +arg+ into a {Rex::Socket::RangeWalker} and append the result into +host_ranges+
-  #
-  # @note This modifies +host_ranges+ in place
-  #
-  # @param arg [String] The thing to turn into a RangeWalker
-  # @param host_ranges [Array] The array of ranges to append
-  # @param required [Boolean] Whether an empty +arg+ should be an error
-  # @return [Boolean] true if parsing was successful or false otherwise
-  def arg_host_range(arg, host_ranges, required=false)
-    if (!arg and required)
-      print_error("Missing required host argument")
-      return false
-    end
-    begin
-      rw = Rex::Socket::RangeWalker.new(arg)
-    rescue
-      print_error("Invalid host parameter, #{arg}.")
-      return false
-    end
-
-    if rw.valid?
-      host_ranges << rw
-    else
-      print_error("Invalid host parameter, #{arg}.")
-      return false
-    end
-    return true
-  end
-
-  #
-  # Parse +arg+ into an array of ports and append the result into +port_ranges+
-  #
-  # Returns true if parsing was successful or nil otherwise.
-  #
-  # NOTE: This modifies +port_ranges+
-  #
-  def arg_port_range(arg, port_ranges, required=false)
-    if (!arg and required)
-      print_error("Argument required for -p")
-      return
-    end
-    begin
-      port_ranges << Rex::Socket.portspec_to_portlist(arg)
-    rescue
-      print_error("Invalid port parameter, #{arg}.")
-      return
-    end
-    return true
-  end
 
   #
   # Takes +host_ranges+, an Array of RangeWalkers, and chunks it up into
