@@ -1,11 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
 require 'rex/proto/http'
-require 'msf/core'
-
 
 class MetasploitModule < Msf::Auxiliary
 
@@ -35,12 +33,11 @@ class MetasploitModule < Msf::Auxiliary
       connect
       res = send_request_raw({ 'uri' => '/', 'method' => 'GET' })
       fp = http_fingerprint(:response => res)
-      print_status("#{ip}:#{rport} #{fp}") if fp
+      print_good("#{ip}:#{rport} #{fp}") if fp
       report_service(:host => rhost, :port => rport, :sname => (ssl ? 'https' : 'http'), :info => fp)
     rescue ::Timeout::Error, ::Errno::EPIPE
     ensure
       disconnect
     end
   end
-
 end
