@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = GoodRanking
 
@@ -473,5 +471,4 @@ exec sp_executesql @z|
 
     return res[:rows][0][0]
   end
-
 end
